@@ -134,7 +134,7 @@ class Client(object):
 
     def upload_document(self, customer_id: str, document: object, verify_name: str = None, verify_address: str = None, tags: list = list()):
         """
-        Uploads document(s) to a customer. Once the document(s) are uploaded, they will be queued for processing by Inscribe’s fraud detection, parsing, 
+        Uploads document(s) to a customer. Once the document(s) are uploaded, they will be queued for processing by Inscribe’s fraud detection, parsing,
         and optionally verification algorithms. The file size limit is 50 MB and the page limit for PDFs is 350.
 
         :param document: The document to be uploaded
@@ -247,7 +247,7 @@ class Client(object):
     @property
     def headers(self):
         if self.access_key and self.secret_key:
-            encoded_keys = base64.encodebytes(f"{self.access_key}:{self.secret_key}".encode("utf-8")).decode("ascii")
+            encoded_keys = base64.b64encode(f"{self.access_key}:{self.secret_key}".encode("utf-8")).decode("ascii")
             return {'Authorization': f"Inscribe {encoded_keys}"}
 
         return {'Authorization': self.api_key}
